@@ -63,6 +63,10 @@ PROXIMITY_IN_MASK        = 1 << 18
 PROXIMITY_OUT_MASK       = 1 << 19
 ALL_EVENTS_MASK          = 0x07FFFF
 
+# GdkFontType's
+FONT_FONT    = 0
+FONT_FONTSET = 0
+
 # GdkNotifyType's
 NOTIFY_ANCESTOR          = 0
 NOTIFY_VIRTUAL           = 1
