@@ -6,8 +6,7 @@
 #
 # TODO
 # 1. document some of this (maybe all of it)
-# 2. add wrappers for some of the GDK types.
-# 3. fix up GtkImage
+# 2. fix up GtkImage (no one has needed it yet so it is low priority)
 
 # The _obj argument in each constructor is used to create a Gtkinter object
 # that coresponds to an already created GTK Object.  It should be possible
@@ -30,6 +29,9 @@ if '--display' in _sys.argv or _os.environ.has_key('DISPLAY'):
 else:
 	print 'No display information -- gtk_init not called'
 
+# this sets up i18n input stuff
+_gtk.gtk_set_locale()
+
 class GtkObject:
 	def __init__(self, _obj=None):
 		if _obj: self._o = _obj; return
@@ -77,14 +79,15 @@ class GtkObject:
 					a[i] = _obj2inst(args[i])
 			a = tuple(a)
 			return apply(self.func, a)
-	def connect(self, name, f):
+	def connect(self, name, f, *extra):
 		callback = self.__cnv(f)
-		return _gtk.gtk_signal_connect(self._o,name,callback.__call__)
+		return _gtk.gtk_signal_connect(self._o,name,callback.__call__,
+					       extra)
 	signal_connect = connect
-	def connect_after(self, name, f):
+	def connect_after(self, name, f, *extra):
 		callback = self.__cnv(f)
 		return _gtk.gtk_signal_connect_after(self._o, name,
-						     callback.__call__)
+						     callback.__call__, extra)
 	signal_connect_after = connect_after
 	def disconnect(self, id):
 		_gtk.gtk_signal_disconnect(self._o, id)
@@ -1144,15 +1147,15 @@ class GtkDrawingArea(GtkWidget):
 		if not self.__win: self.__cache_win()
 		_gtk.gdk_draw_arc(self.__win, gc, x, y, width, height, angle1,
 				  angle2)
-	def draw_polygon(self, gc, points):
+	def draw_polygon(self, gc, fill, points):
 		if not self.__win: self.__cache_win()
-		_gtk.gdk_draw_polygon(self.__win, gc, points)
-	def draw_string(self, gc, x, y, string):
+		_gtk.gdk_draw_polygon(self.__win, gc, fill, points)
+	def draw_string(self, font, gc, x, y, string):
 		if not self.__win: self.__cache_win()
-		_gtk.gdk_draw_string(self.__win, gc, x, y, string)
-	def draw_text(self, gc, x, y, text):
+		_gtk.gdk_draw_string(self.__win, font, gc, x, y, string)
+	def draw_text(self, font, gc, x, y, text):
 		if not self.__win: self.__cache_win()
-		_gtk.gdk_draw_text(self.__win, gc, x, y, text)
+		_gtk.gdk_draw_text(self.__win, font, gc, x, y, text)
 	def draw_pixmap(self, gc, src, xsrc,ysrc, xdest,ydest, width,height):
 		if not self.__win: self.__cache_win()
 		_gtk.gdk_draw_pixmap(self.__win, gc, src, xsrc,ysrc,
@@ -1609,7 +1612,7 @@ def rc_parse_string(string):
 def load_font(font):
 	return _gtk.gdk_font_load(font)
 def load_fontset(fontset):
-	return _gtk.gdk_fondset_load(fontset)
+	return _gtk.gdk_fontset_load(fontset)
 
 # colour allocation
 def colour_alloc(parent, red, green=None, blue=None):
@@ -1654,12 +1657,12 @@ def draw_rectangle(drawable, gc, fill, x, y, width, height):
 def draw_arc(drawable, gc, x, y, width, height, angle1, angle2):
 	_gtk.gdk_draw_arc(drawable, gc, x, y, width, height, angle1,
 			  angle2)
-def draw_polygon(drawable, gc, points):
-	_gtk.gdk_draw_polygon(drawable, gc, points)
-def draw_string(drawable, gc, x, y, string):
-	_gtk.gdk_draw_string(drawable, gc, x, y, string)
-def draw_text(drawable, gc, x, y, text):
-	_gtk.gdk_draw_text(drawable, gc, x, y, text)
+def draw_polygon(drawable, gc, fill, points):
+	_gtk.gdk_draw_polygon(drawable, gc, fill, points)
+def draw_string(drawable, font, gc, x, y, string):
+	_gtk.gdk_draw_string(drawable, font, gc, x, y, string)
+def draw_text(drawable, font, gc, x, y, text):
+	_gtk.gdk_draw_text(drawable, font, gc, x, y, text)
 def draw_pixmap(drawable, gc, src, xsrc,ysrc, xdest,ydest, width,height):
 	_gtk.gdk_draw_pixmap(drawable, gc, src, xsrc,ysrc,
 			     xdest,ydest, width,height)
