@@ -10,6 +10,51 @@ def delete_event(win, event=None):
 	# don't destroy window -- just leave it hidden
 	return TRUE
 
+def create_statusbar_test(_button):
+	if not wins.has_key('statusbar_test'):
+		win = GtkDialog()
+		wins["statusbar_test"] = win
+		win.connect("delete_event", delete_event)
+		win.set_title("Status Bar Test")
+
+		vbox = GtkVBox()
+		win.action_area.pack_start( vbox )
+		hbox = GtkHBox()
+		vbox.add( hbox )
+		statusbar = win.statusbar = GtkStatusbar()
+		vbox.add( statusbar )
+		statusbar.show()
+		
+		c = win.context_id = statusbar.get_context_id("test")
+		statusbar.push( c, "First message")
+		def pop_statusbar_test(_b, sbar = statusbar, context = c):
+			sbar.pop( context )
+		def push_statusbar_test(_b, sbar = statusbar, context = c):
+			import time
+			sbar.push( context, "Message "+str(time.time() ))
+
+		button = GtkButton("Pop")
+		button.connect("clicked", pop_statusbar_test)
+		hbox.add(button)
+		button.show()
+
+		button = GtkButton("Push")
+		button.connect("clicked", push_statusbar_test)
+		hbox.add(button)
+		button.show()
+
+		button = GtkButton("close")
+		button.connect("clicked", win.hide)
+		hbox.add(button)
+		button.set_flags(CAN_DEFAULT)
+		button.grab_default()
+		button.show()
+
+		hbox.show()
+		vbox.show()
+	wins["statusbar_test"].show()
+
+		
 def create_buttons(_button):
 	if not wins.has_key("buttons"):
 		win = GtkWindow()
@@ -956,21 +1001,24 @@ def create_rulers(_button):
 		ruler = GtkHRuler()
 		ruler.set_range(5, 15, 0, 20)
 		ruler.set_metric(PIXELS)
-		# XXX decide how to connect motion event
+		def motion_notify(obj, event, ruler=ruler):
+			return ruler.emit("motion_notify_event", event)
+		win.connect("motion_notify_event", motion_notify)
 		table.attach(ruler, 1,2, 0,1, yoptions=FILL)
 		ruler.show()
 
 		ruler = GtkVRuler()
 		ruler.set_range(5, 15, 0, 20)
 		ruler.set_metric(PIXELS)
-		# XXX notify ,,,
+		def motion_notify(obj, event, ruler=ruler):
+			return ruler.emit("motion_notify_event", event)
+		win.connect("motion_notify_event", motion_notify)
 		table.attach(ruler, 0,1, 1,2, xoptions=FILL)
 		ruler.show()
 
-		# remove when fixed
-		label = GtkLabel("Sometime I'll really\n" +
-				 "have to fix these\n" +
-				 "rulers.")
+		label = GtkLabel("The rulers now work!\n" +
+				 "They use the new interface to\n" +
+				 "gtk_signal_emit.")
 		table.attach(label, 1,2, 1,2)
 		label.show()
 
@@ -1423,6 +1471,7 @@ def create_main_window():
 		"test timeout": create_timeout_test,
 		"test idle": create_idle_test,
 		"test": None, #create_test
+		"status bar": create_statusbar_test,
 	}
 	win = GtkWindow()
 	win.set_name("main window")
